==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_fields/QUOTATIONTOTALS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;


/**
 * <p>Classe Java pour QUOTATIONTOTALS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="QUOTATIONTOTALS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICELINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOTALTAXAMOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTTOTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICETOTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOTALVALUE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUOTATIONTOTALS_Type", propOrder = {
    "partlinecount",
    "servicelinecount",
    "rfqlinecount",
    "totaltaxamount",
    "parttotal",
    "servicetotal",
    "totalvalue"
})
public class QUOTATIONTOTALS_Type {

    @XmlElement(name = "PARTLINECOUNT")
    protected Long partlinecount;
    @XmlElement(name = "SERVICELINECOUNT")
    protected Long servicelinecount;
    @XmlElement(name = "RFQLINECOUNT")
    protected Long rfqlinecount;
    @XmlElement(name = "TOTALTAXAMOUNT")
    protected AMOUNT totaltaxamount;
    @XmlElement(name = "PARTTOTAL")
    protected AMOUNT parttotal;
    @XmlElement(name = "SERVICETOTAL")
    protected AMOUNT servicetotal;
    @XmlElement(name = "TOTALVALUE")
    protected AMOUNT totalvalue;

    /**
     * Obtient la valeur de la propriété partlinecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPARTLINECOUNT() {
        return partlinecount;
    }

    /**
     * Définit la valeur de la propriété partlinecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPARTLINECOUNT(Long value) {
        this.partlinecount = value;
    }

    /**
     * Obtient la valeur de la propriété servicelinecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSERVICELINECOUNT() {
        return servicelinecount;
    }

    /**
     * Définit la valeur de la propriété servicelinecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSERVICELINECOUNT(Long value) {
        this.servicelinecount = value;
    }

    /**
     * Obtient la valeur de la propriété rfqlinecount.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRFQLINECOUNT() {
        return rfqlinecount;
    }

    /**
     * Définit la valeur de la propriété rfqlinecount.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRFQLINECOUNT(Long value) {
        this.rfqlinecount = value;
    }

    /**
     * Obtient la valeur de la propriété totaltaxamount.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTOTALTAXAMOUNT() {
        return totaltaxamount;
    }

    /**
     * Définit la valeur de la propriété totaltaxamount.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTOTALTAXAMOUNT(AMOUNT value) {
        this.totaltaxamount = value;
    }

    /**
     * Obtient la valeur de la propriété parttotal.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getPARTTOTAL() {
        return parttotal;
    }

    /**
     * Définit la valeur de la propriété parttotal.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setPARTTOTAL(AMOUNT value) {
        this.parttotal = value;
    }

    /**
     * Obtient la valeur de la propriété servicetotal.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getSERVICETOTAL() {
        return servicetotal;
    }

    /**
     * Définit la valeur de la propriété servicetotal.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setSERVICETOTAL(AMOUNT value) {
        this.servicetotal = value;
    }

    /**
     * Obtient la valeur de la propriété totalvalue.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTOTALVALUE() {
        return totalvalue;
    }

    /**
     * Définit la valeur de la propriété totalvalue.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTOTALVALUE(AMOUNT value) {
        this.totalvalue = value;
    }

}

==> eam-wshub-proxyclient-11.7-3-sources.jar: net/datastream/schemas/mp_fields/QUOTATIONTOTALS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.AMOUNT;


/**
 * <p>Java class for QUOTATIONTOTALS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="QUOTATIONTOTALS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTLINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICELINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RFQLINECOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOTALTAXAMOUNT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTTOTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERVICETOTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOTALVALUE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "QUOTATIONTOTALS_Type", propOrder = {
    "partlinecount",
    "servicelinecount",
    "rfqlinecount",
    "totaltaxamount",
    "parttotal",
    "servicetotal",
    "totalvalue"
})
public class QUOTATIONTOTALS_Type {

    @XmlElement(name = "PARTLINECOUNT")
    protected Long partlinecount;
    @XmlElement(name = "SERVICELINECOUNT")
    protected Long servicelinecount;
    @XmlElement(name = "RFQLINECOUNT")
    protected Long rfqlinecount;
    @XmlElement(name = "TOTALTAXAMOUNT")
    protected AMOUNT totaltaxamount;
    @XmlElement(name = "PARTTOTAL")
    protected AMOUNT parttotal;
    @XmlElement(name = "SERVICETOTAL")
    protected AMOUNT servicetotal;
    @XmlElement(name = "TOTALVALUE")
    protected AMOUNT totalvalue;

    /**
     * Gets the value of the partlinecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getPARTLINECOUNT() {
        return partlinecount;
    }

    /**
     * Sets the value of the partlinecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setPARTLINECOUNT(Long value) {
        this.partlinecount = value;
    }

    /**
     * Gets the value of the servicelinecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSERVICELINECOUNT() {
        return servicelinecount;
    }

    /**
     * Sets the value of the servicelinecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSERVICELINECOUNT(Long value) {
        this.servicelinecount = value;
    }

    /**
     * Gets the value of the rfqlinecount property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getRFQLINECOUNT() {
        return rfqlinecount;
    }

    /**
     * Sets the value of the rfqlinecount property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setRFQLINECOUNT(Long value) {
        this.rfqlinecount = value;
    }

    /**
     * Gets the value of the totaltaxamount property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTOTALTAXAMOUNT() {
        return totaltaxamount;
    }

    /**
     * Sets the value of the totaltaxamount property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTOTALTAXAMOUNT(AMOUNT value) {
        this.totaltaxamount = value;
    }

    /**
     * Gets the value of the parttotal property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getPARTTOTAL() {
        return parttotal;
    }

    /**
     * Sets the value of the parttotal property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setPARTTOTAL(AMOUNT value) {
        this.parttotal = value;
    }

    /**
     * Gets the value of the servicetotal property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getSERVICETOTAL() {
        return servicetotal;
    }

    /**
     * Sets the value of the servicetotal property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setSERVICETOTAL(AMOUNT value) {
        this.servicetotal = value;
    }

    /**
     * Gets the value of the totalvalue property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTOTALVALUE() {
        return totalvalue;
    }

    /**
     * Sets the value of the totalvalue property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTOTALVALUE(AMOUNT value) {
        this.totalvalue = value;
    }

}
